@@ -3,13 +3,13 @@
 
 
 import re
-import sys
 import json
 import webservice
 
 
 UA = 'isbntools (gzip)'
-SERVICE_URL = 'http://xisbn.worldcat.org/webservices/xid/isbn/%s?method=getMetadata&format=json&fl=*'
+SERVICE_URL = 'http://xisbn.worldcat.org/webservices/xid/isbn/%s?'\
+    'method=getMetadata&format=json&fl=*'
 OUT_OF_SERVICE = 'Temporarily out of service'
 BOOK_NOT_FOUND = 'No results match your search'
 PATT_YEAR = re.compile(r'\d{4}')
@@ -67,9 +67,3 @@ def query(isbn):
     """
     query = WCATQuery(isbn)
     return query.records()
-
-
-if __name__ == "__main__":
-    r = query(sys.argv[1].replace('-', ''))
-    sys.stdout.write('ISBN-13: %s\nTitle: %s\nAuthors: %s\nPublisher: %s\nYear: %s\n' %
-          (r['ISBN-13'], r['Title'], r['Authors'], r['Publisher'], r['Year']))
